package net.wanji.utc.service;

import net.wanji.utc.common.Result;
import net.wanji.utc.vo.PhaseLock;

/**
 * 控制指令 service
 *
 * @author wuxiaokai
 * @date 2022/11/15 14:02:36
 */
public interface ControlCommandService {

    /**
     * 方案下发
     */
    <T> Result<T> schemeSend();

    /**
     * 计划下发
     */
    <T> Result<T> planSend();

    /**
     * 时间表下发
     */
    <T> Result<T> scheduleSend();

    /**
     * 锁定控制
     *
     * @param signalId 信号机编号
     * @param locks    相位锁定实体类
     * @return {@link Result}<{@link T}>
     */
    <T> Result<T> lockControl(String signalId, PhaseLock... locks);

    /**
     * 步进控制
     *
     * @param signalId   信号机编号
     * @param sourceType 厂家简称 QS/SCATS/HS/HK
     * @param signalType 信号机类型 QS/SCATS/HS/HK
     * @param command    1 开始步进 0 取消步进
     * @param stepNum    0 顺序步进 n 跳过n个相位
     * @return {@link Result}<{@link T}>
     */
    <T> Result<T> stepControl(String signalId, String sourceType, String signalType, Integer command, Integer stepNum);

    /**
     * 全红控制
     *
     * @param signalId   信号机编号
     * @param sourceType 厂家简称
     * @param signalType 信号机类型
     * @param command    1 全红控制 0 取消全红
     * @return {@link Result}<{@link T}>
     */
    <T> Result<T> allRedControl(String signalId, String sourceType, String signalType, Integer command);

    /**
     * 黄闪控制
     *
     * @param signalId   信号机编号
     * @param sourceType 厂家简称
     * @param signalType 信号机类型
     * @param command    1 黄闪控制 0 取消黄闪
     * @return {@link Result}<{@link T}>
     */
    <T> Result<T> yellowLightControl(String signalId, String sourceType, String signalType, Integer command);

    /**
     * 关灯控制
     *
     * @param signalId   信号机编号
     * @param sourceType 厂家简称
     * @param signalType 信号机类型
     * @param command    1 开灯 0 关灯
     * @return {@link Result}<{@link T}>
     */
    <T> Result<T> closeLightControl(String signalId, String sourceType, String signalType, Integer command);

    /**
     * 恢复时间表
     *
     * @param signalId   信号机编号
     * @param sourceType 厂家简称 QS/SCATS/HS/HK
     * @param signalType 信号机类型 QS/SCATS/HS/HK
     * @param command    1 恢复
     * @return {@link Result}<{@link T}>
     */
    <T> Result<T> recoverSchedule(String signalId, String sourceType, String signalType, Integer command);

    /**
     * 相位配时下发
     */
    <T> Result<T> phaseTimingSend();

    /**
     * 相位差下发
     */
    <T> Result<T> phaseDiffSend();

}
